package Drawnings;

import java.awt.*;
import Entities.*;
import MovementStrategy.*;

public class DrawingAirbus {

    public EntityAirbus entityAirbus;
    public DrawingPortholes _portholes;
    private int _pictureWidth;
    private int _pictureHeight;
    private int _startPosX;
    private int _startPosY;
    private int _airbusWidth = 210;
    private int _airbusHeight = 100;

    public void Init(int speed, float weight, Color bodyColor, Color additionalColor, boolean isCompartment, boolean isadditionalEngine, int countPortholes, int width, int height) {
        if (width < _airbusHeight || height < _airbusWidth)
            return;
        _pictureWidth = width;
        _pictureHeight = height;
        entityAirbus = new EntityAirbus();
        entityAirbus.Init(speed, weight, bodyColor, additionalColor, isCompartment, isadditionalEngine);

        _portholes = new DrawingPortholes();
        _portholes.SetCount(countPortholes);
    }

    public void SetPosition (int x, int y) {
        if (x > _pictureWidth || y > _pictureHeight || x < 0 || y < 0)
        {
            _startPosX = 0;
            _startPosY = 0;
        }
        else
        {
            _startPosX = x;
            _startPosY = y;
        }
    }

    public void MoveTransport(Direction direction){
        if (entityAirbus == null) {
            return;
        }

        switch (direction) {
            case Left:
            if (_startPosX - entityAirbus.Step > 5)
            {
                _startPosX -= entityAirbus.Step;
            }
            break;
        case Right:
            if (_startPosX + _airbusWidth + entityAirbus.Step < _pictureWidth)
            {
                _startPosX += entityAirbus.Step;
            }
            break;
        case Up:
            if (_startPosY - entityAirbus.Step > 0)
            {
                _startPosY -= entityAirbus.Step;
            }
            break;
        case Down:
            if (_startPosY + _airbusHeight + entityAirbus.Step < _pictureHeight)
            {
                _startPosY += entityAirbus.Step;
            }
            break;
        }
    }

    public void DrawTransport(Graphics2D g) {

        if (entityAirbus == null) {
            return;
        }
        // иллюминаторы
        _portholes.Draw(g, _startPosX+30, _startPosY+34);

        g.setColor(Color.BLACK);
//Тело
        g.drawRect(_startPosX + 5, _startPosY + 50, 170, 30);
        g.drawArc(_startPosX - 5, _startPosY + 50, 20, 30, 90, 180);
//Заднее крыло
        g.drawLine( _startPosX, _startPosY, _startPosX + 50, _startPosY + 50);
        g.drawLine( _startPosX, _startPosY, _startPosX, _startPosY + 52);
//Заднее боковые крылья
        g.drawOval(_startPosX - 7, _startPosY + 45, 30, 8);
        g.fillOval(_startPosX - 7, _startPosY + 45, 30, 8);
//Нос
        g.drawLine( _startPosX + 175, _startPosY + 50, _startPosX + 200, _startPosY + 65);
        g.drawLine( _startPosX + 200, _startPosY + 65, _startPosX + 175, _startPosY + 80);
        g.drawLine( _startPosX + 175, _startPosY + 50, _startPosX + 175, _startPosY + 80);
        g.drawLine( _startPosX + 175, _startPosY + 65, _startPosX + 200, _startPosY + 65);
//Крылья
        g.drawArc(_startPosX + 49, _startPosY + 62, 5, 5, 90, 180);
        g.drawLine( _startPosX + 51, _startPosY + 62, _startPosX + 140, _startPosY + 62);
        g.drawArc( _startPosX + 137, _startPosY + 62, 5, 5, 2790, 180);
        g.drawLine( _startPosX + 51, _startPosY + 67, _startPosX + 140, _startPosY + 67);
//Задние шасси
        g.drawLine(_startPosX + 55, _startPosY + 80, _startPosX + 55, _startPosY + 90);
        g.drawOval(_startPosX + 47, _startPosY + 90, 5, 5);
        g.drawOval( _startPosX + 57, _startPosY + 90, 5, 5);
//Передние шасси
        g.drawLine( _startPosX + 165, _startPosY + 80, _startPosX + 165, _startPosY + 90);
        g.drawOval( _startPosX + 163, _startPosY + 91, 5, 5);
//Пассажирсакий доп. отсек
        if (entityAirbus.IsCompartment())
        {
            g.setColor(entityAirbus.getAdditionalColor());
            g.drawArc(_startPosX + 60, _startPosY + 28, 115, 45, 0, 180);
            g.fillArc(_startPosX + 60, _startPosY + 28, 115, 45, 0, 180);
        }
// Доп. двигатели
        if (entityAirbus.IsAdditionalEngine())
        {
            g.drawLine(_startPosX + 95, _startPosY + 68, _startPosX + 95, _startPosY + 75);
            g.setColor(entityAirbus.getAdditionalColor());
            int[] xPolygon = { _startPosX + 83, _startPosX + 103, _startPosX + 103, _startPosX + 83, _startPosX + 83};
            int[] yPolygon = {_startPosY + 78, _startPosY + 73, _startPosY + 93, _startPosY + 88, _startPosY + 78};
            g.drawPolygon(xPolygon, yPolygon, xPolygon.length);
            g.fillPolygon(xPolygon, yPolygon, xPolygon.length);
        }
    }
}
